==> nomachine-8.11.3-1-x86_64.pkg.tar.zst: NX/lib/perl/nxserver/Exception/InfoTrace.pm <==
############################################################################
#                                                                          #
#  Copyright (c) 2001, 2024 NoMachine, http://www.nomachine.com.           #
#                                                                          #
#  NXSERVER, NX protocol compression and NX extensions to this software    #
#  are copyright of NoMachine. Redistribution and use of the present       #
#  software is allowed according to terms specified in the file LICENSE    #
#  which comes in the source distribution.                                 #
#                                                                          #
#  Check http://www.nomachine.com/licensing.html for applicability.        #
#                                                                          #
#  NX and NoMachine are trademarks of NoMachine S.a.r.l.                   #
#                                                                          #
#  All rights reserved.                                                    #
#                                                                          #
############################################################################
sub Exception::InfoTrace::BEGIN{package Exception::InfoTrace;no warnings;require
 base;do{"\x62\x61\x73\x65"->import (
"\x45\x78\x63\x65\x70\x74\x69\x6f\x6e\x3a\x3a\x42\x61\x73\x65")};}sub 
Exception::InfoTrace::BEGIN{package Exception::InfoTrace;no warnings;require 
overload;do{"\x6f\x76\x65\x72\x6c\x6f\x61\x64"->import ("\x22\x22",
"\x73\x74\x72\x69\x6e\x67\x69\x66\x79")};}sub Exception::InfoTrace::notify{
package Exception::InfoTrace;no warnings;(my $self=shift (@_));(my $text=$self->
text);NXMsg::register_response ((""),"\x65\x49\x6e\x66\x6f\x54\x72\x61\x63\x65",
(0x20d5+ 2184-0x270a));NXMsg::send_response (
"\x65\x49\x6e\x66\x6f\x54\x72\x61\x63\x65","\x67\x65\x6e\x65\x72\x61\x6c",$text)
;(my $trace=$self->stacktrace);($trace=~ s/\n[^\w]+/\n    / );main::nxwrite (
main::nxgetSTDOUT (),("\x20\x20\x20\x20".$trace));}package Exception::InfoTrace;
no warnings;"\x3f\x3f\x3f";

==> nomachine-8.12.12-1-x86_64.pkg.tar.zst: NX/lib/perl/nxserver/Exception/InfoTrace.pm <==
############################################################################
#                                                                          #
#  Copyright (c) 2001, 2024 NoMachine, http://www.nomachine.com.           #
#                                                                          #
#  NXSERVER, NX protocol compression and NX extensions to this software    #
#  are copyright of NoMachine. Redistribution and use of the present       #
#  software is allowed according to terms specified in the file LICENSE    #
#  which comes in the source distribution.                                 #
#                                                                          #
#  Check http://www.nomachine.com/licensing.html for applicability.        #
#                                                                          #
#  NX and NoMachine are trademarks of NoMachine S.a.r.l.                   #
#                                                                          #
#  All rights reserved.                                                    #
#                                                                          #
############################################################################
sub Exception::InfoTrace::BEGIN{package Exception::InfoTrace;no warnings;require
 base;do{"\x62\x61\x73\x65"->import (
"\x45\x78\x63\x65\x70\x74\x69\x6f\x6e\x3a\x3a\x42\x61\x73\x65")};}sub 
Exception::InfoTrace::BEGIN{package Exception::InfoTrace;no warnings;require 
overload;do{"\x6f\x76\x65\x72\x6c\x6f\x61\x64"->import ("\x22\x22",
"\x73\x74\x72\x69\x6e\x67\x69\x66\x79")};}sub Exception::InfoTrace::notify{
package Exception::InfoTrace;no warnings;(my $self=shift (@_));(my $text=$self->
text);NXMsg::register_response ((""),"\x65\x49\x6e\x66\x6f\x54\x72\x61\x63\x65",
(0x0693+ 5766-0x1ac6));NXMsg::send_response (
"\x65\x49\x6e\x66\x6f\x54\x72\x61\x63\x65","\x67\x65\x6e\x65\x72\x61\x6c",$text)
;(my $trace=$self->stacktrace);($trace=~ s/\n[^\w]+/\n    / );main::nxwrite (
main::nxgetSTDOUT (),("\x20\x20\x20\x20".$trace));}package Exception::InfoTrace;
no warnings;"\x3f\x3f\x3f";
